pub mod local_fs;
pub mod mode_authorizer;

use btlib::{
    crypto::{ConcreteCreds, Creds},
    Epoch, Principaled,
};
use core::time::Duration;
use lazy_static::lazy_static;

lazy_static! {
    static ref ROOT_CREDS: ConcreteCreds = ConcreteCreds::generate().unwrap();
    static ref NODE_CREDS: ConcreteCreds = {
        let root_creds = &ROOT_CREDS;
        let mut node_creds = ConcreteCreds::generate().unwrap();
        let writecap = root_creds
            .issue_writecap(
                node_creds.principal(),
                vec![],
                Epoch::now() + Duration::from_secs(3600),
            )
            .unwrap();
        node_creds.set_writecap(writecap);
        node_creds
    };
}

pub fn node_creds() -> &'static ConcreteCreds {
    &NODE_CREDS
}
